#include <iostream>
#include <fstream>
#include <cmath>
#include <cstdlib>
#include <map>
#include <set>
#include <vector>
#include <cstring>
#include <string>
#include <algorithm>
#include <queue>
#include <cassert>

using namespace std;

const char TABLE = 'T';
const char CHAIR = 'C';
const char EMPTY = '.';

const int nmax = 2e3;
const int NMAX = nmax * nmax;
char s[nmax][nmax];
int color[nmax][nmax];
int n, m, N, M;
int dx[] = { 0, 0, -1, 1 };
int dy[] = { -1, 1, 0, 0 };

vector <int> g[nmax * nmax];

bool valid(int i, int j) {
	return 0 <= i && i < N && 0 <= j && j < M;
}

void dfs(int i, int j, int c) {
	if (color[i][j] != 0) return;
	if (!valid(i, j)) return;
	if (s[i][j] != EMPTY) return;
	color[i][j] = c;
	for (int k = 0; k < 4; k ++) {
		int i1 = i + dx[k];
		int j1 = j + dy[k];
		dfs(i1, j1, c);
	}
}

struct edge {
	int i, j;
	int c1, c2;
	edge(int I, int J, int C1, int C2) {
		i = I;
		j = J;
		c1 = C1;
		c2 = C2;
	}	
};

vector <edge> e;

int p[NMAX];

void init_dsu() {
	for (int i = 0; i < NMAX; i ++) {
		p[i] = i;
	}
}

int get(int v) {
	if (p[v] == v) {
		return v;
	} else {
		return (p[v] = get(p[v]));
	}
}

bool unite(int v, int u) {
	v = get(v);
	u = get(u);
	p[v] = u;
	return v != u;
}

int main()
{
	scanf("%d%d", &n, &m); 
	n *= 3; m *= 3;
	N = n + 2;
	M = m + 2;
	for (int i = 0; i < N; i ++) {
		for (int j = 0; j < M; j ++) {
			s[i][j] = EMPTY;
		}
	}
	for (int i = 1; i <= n; i ++) { 
		scanf("%s", s[i] + 1);
		s[i][m + 1] = '.';
	}
	int C = 0;
	for (int i = 0; i < N; i ++) {
		for (int j = 0; j < M; j ++) {
			if (s[i][j] == EMPTY && color[i][j] == 0) {
				dfs(i, j, ++ C);
			}
		}		
	}
	for (int i = 0; i < N; i ++)
		for (int j = 0; j < M; j ++) 
			for (int k = 0; k < 4; k ++) {
				int i1 = i + dx[k];
				int j1 = j + dy[k];
				if (s[i][j] == CHAIR && valid(i1, j1) && s[i1][j1] == CHAIR) {
					int si = -dy[k];
					int sj = dx[k];
					if (valid(i + si, j + sj) && valid(i - si, j - sj)) {
						assert(s[i + si][j + sj] == EMPTY);
						assert(s[i - si][j - sj] == EMPTY);
						int c1 = color[i + si][j + sj];
						int c2 = color[i - si][j - sj];
						e.push_back(edge(i, j, c1, c2));
					}
				}
			}
	init_dsu();
	int res = 0;
	for (int i = 0; i < e.size(); i ++)
		if (unite(e[i].c1, e[i].c2)) {
			s[e[i].i][e[i].j] = EMPTY;
			res ++;
		}
	fprintf(stderr, "%d\n", res);
	for (int i = 1; i <= n; i ++) 
	{
		s[i][m + 1] = '\0';
		printf("%s\n", s[i] + 1);	
	}
	return 0;
}
