#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>

enum
{
  RUN_OK               = 0,
  RUN_COMPILE_ERR      = 1,
  RUN_RUN_TIME_ERR     = 2,
  RUN_TIME_LIMIT_ERR   = 3,
  RUN_PRESENTATION_ERR = 4,
  RUN_WRONG_ANSWER_ERR = 5,
  RUN_CHECK_FAILED     = 6,
  RUN_PARTIAL          = 7,
  RUN_ACCEPTED         = 8,
  RUN_IGNORED          = 9,
  RUN_DISQUALIFIED     = 10,
  RUN_PENDING          = 11,
  RUN_MEM_LIMIT_ERR    = 12,
  RUN_SECURITY_ERR     = 13,
  RUN_STYLE_ERR        = 14,
  RUN_WALL_TIME_LIMIT_ERR = 15,
  RUN_PENDING_REVIEW   = 16,
  RUN_REJECTED         = 17,
};

static void die(const char *format, ...)
    __attribute__((noreturn, format(printf, 1, 2)));
static void die(const char *format, ...)
{
    va_list args;
    char buf[1024];

    va_start(args, format);
    vsnprintf(buf, sizeof(buf), format, args);
    va_end(args);

    fprintf(stderr, "valuer fatal error: %s\n", buf);
    exit(RUN_CHECK_FAILED);
}

// experimental interactive valuer
int main(int argc, char *argv[])
{
    if (!getenv("EJUDGE")) die("expected EJUDGE environment");
    if (!getenv("EJUDGE_INTERACTIVE")) die("expected EJUDGE_INTERACTIVE");
    if (!getenv("EJUDGE_USER_SCORE")) die("expected EJUDGE_USER_SCORE");
    //if (!getenv("EJUDGE_MARKED")) die("expected EJUDGE_MARKED");
    FILE *fcmt = fopen(argv[1], "w");

    int total_count = -2;
    if (scanf("%d", &total_count) != 1 || total_count != -1)
        die("expected total_count == -1");

    // test groups:
    // 1 :    from statement, 0
    // 2-7:   30
    // 8-11:  30
    // 12-23: 40 offline

    int group0_tests_passed = 0; // 1 test
    int group1_tests_passed = 0; // 6 tests
    int group2_tests_passed = 0; // 4 tests
    int group3_tests_passed = 0; // 12 tests

    int cur_test = 0, status, test_score, ttime;
    while (scanf("%d%d%d", &status, &test_score, &ttime) == 3) {
        ++cur_test;
        if (cur_test >= 1 && cur_test <= 1) {
            if (status == RUN_OK) ++group0_tests_passed;
            printf("-1\n");
            fflush(stdout);
        } else if (cur_test >= 2 && cur_test <= 7) {
            if (status == RUN_OK) {
                ++group1_tests_passed;
                printf("-1\n");
            } else {
                printf("-8\n");
                if (cur_test < 7) {
                    fprintf(fcmt, "Тестирование на тестах %d-%d не выполнялось, "
                            "так как тест %d не пройден, и оценка за группу тестов %d - 0 баллов.\n",
                            cur_test + 1, 7, cur_test, 1);
                }
                cur_test = 7;
            }
            fflush(stdout);
        } else if (cur_test >= 8 && cur_test <= 11) {
            if (status == RUN_OK) {
                ++group2_tests_passed;
                if (cur_test == 11 &&
                    (/*group0_tests_passed != 1
                     ||*/ group1_tests_passed != 6
                     || group2_tests_passed != 4))
                    break;
                printf("-1\n");
            } else {
                if (cur_test < 11) {
                    fprintf(fcmt, "Тестирование на тестах %d-%d не выполнялось, "
                            "так как тест %d не пройден, и оценка за группу тестов %d - 0 баллов.\n",
                            cur_test + 1, 11, cur_test, 2);
                }
                break;
            }
            fflush(stdout);
        } else if (cur_test >= 12 && cur_test <= 23) {
            if (status == RUN_OK) {
                ++group3_tests_passed;
                printf("-1\n");
            } else {
                printf("-24\n");
                cur_test = 23;
            }
            fflush(stdout);
        } else {
            die("unexpected test number");
        }
    }

    int total_score = 0;
    int user_status = RUN_PARTIAL;
    int user_score = 0;
    int user_tests_passed = 0;

    if (group1_tests_passed == 6) {
        total_score += 30;
        user_score += 30;
    }
    if (group2_tests_passed == 4) {
        total_score += 30;
        user_score += 30;
    }
    if (group3_tests_passed == 12) {
        total_score += 40;
    }
    if (user_score == 60 && group0_tests_passed == 1) user_status = RUN_OK;
    user_tests_passed = group0_tests_passed + group1_tests_passed + group2_tests_passed;
    printf("%d %d %d %d\n",
           total_score, user_status, user_score, user_tests_passed);
    if (user_score != 60) {
        fprintf(fcmt, "Решение не будет тестироваться на тестах %d-%d после окончания тура!\n",
                12, 23);
    }
    fclose(fcmt);
    return 0;
}

/*
 * Local variables:
 *  c-basic-offset: 4
 * End:
 */
