#include <cassert>
#include <cstdlib>
#include <map>
#include <vector>
#include <cstring>
#include <cstdio>
#include <cctype>
#include <string>
#include <iostream>
using namespace std;
#define pb push_back

const int max_priority = 5;
const int max_sum = 200000;
const int L = 500;

struct bigint {
	int len, sign, *num;
	bool is_boolean;
	bigint& operator=(const bigint& other) {
		sign = other.sign;
		len = other.len;
		num = new int[len];
		memcpy(num, other.num, len * sizeof(int));
		is_boolean = other.is_boolean;
		return *this;
	}
	bigint(bool t) {
		num = new int[1];
		sign = 1;
		len = (int) t;
		num[0] = (int) t;
		is_boolean = true;
	}
	bigint() {
		len = 0;
		num = 0;
		sign = 1;
		is_boolean = false;
	}
	bigint(string s) {
		len = s.length();
		num = new int[len];
		memset(num, 0, len * sizeof(int));
		sign = 1;
		assert(len <= L);
		for (int i = 0; i < len; ++i) {
			assert(isdigit(s[i]));
			num[len - i - 1] = (s[i] - '0');
		}
		trim();
		is_boolean = false;
	}
	void trim() {
		while ((len > 0) && (num[len - 1] == 0))
			--len;
		if (len == 0)
			sign = 1;
	}
	void correct() {
		for (int i = 0; i < len; ++i)
			if (num[i] >= 10) {
				num[i + 1] += num[i] / 10;
				num[i] %= 10;
			}
	}
	int& operator[](int index) {
		return num[index];
	}
	int operator[](int index) const {
		return num[index];
	}
	bigint negate() const {
		bigint res;
		res.len = len;
		res.num = new int[res.len];
		memcpy(res.num, num, res.len * sizeof(int));
		res.sign = -sign;
		if (res.len == 0)
			res.sign = 1;
		return res;
	}
	bool is_true() const {
		assert(is_boolean);
		return (len > 0);
	}
	string to_string() const {
		string res = "";
		if (sign == -1)
			res += "-";
		for (int i = len - 1; i >= 0; --i)
			res += (char) ('0' + num[i]);
		return (res != "") ? res : "0";
	}
};

bool operator<(const bigint& a, const bigint& b) {
	if (a.sign != b.sign)
		return a.sign < b.sign;
	if (a.sign == -1)
		return b.negate() < a.negate();
	if (a.len != b.len)
		return a.len < b.len;
	for (int i = a.len - 1; i >= 0; --i)
		if (a[i] != b[i])
			return a[i] < b[i];
	return false;
}

bool operator==(const bigint& a, const bigint& b) {
	return !((a < b) || (b < a));
}

bool operator<=(const bigint& a, const bigint& b) {
	return !(b < a);
}

bool operator||(const bigint& a, const bigint& b) {
	return a.is_true() || b.is_true();
}

bool operator&&(const bigint& a, const bigint& b) {
	return a.is_true() && b.is_true();
}

bool operator!(const bigint& a) {
	return !a.is_true();
}

bigint operator-(const bigint &a, const bigint &b);

bigint operator+(const bigint &a, const bigint &b) {
	if (b.sign < 0)
		return a - b.negate();
	if (a.sign < 0)
		return b - a.negate();
	assert(a.sign >= 0);
	assert(b.sign >= 0);
	bigint c;
	c.len = max(a.len, b.len) + 1;
	c.num = new int[c.len];
	memset(c.num, 0, c.len * sizeof(int));
	for (int i = 0; i < a.len; ++i)
		c[i] += a[i];
	for (int i = 0; i < b.len; ++i)
		c[i] += b[i];
	c.correct();
	c.trim();
	assert(c.len <= L);
	return c;
}

bigint operator-(const bigint &a, const bigint &b) {
	if (a < b)
		return (b - a).negate();
	if (b.sign < 0)
		return a + b.negate();
	assert(a.sign >= 0);
	assert(b.sign >= 0);
	bigint c;
	c.len = a.len;
	c.num = new int[c.len];
	memset(c.num, 0, c.len * sizeof(int));
	for (int i = 0; i < c.len; ++i) {
		c[i] += a[i];
		if (i < b.len)
			c[i] -= b[i];
		if (c[i] < 0) {
			c[i] += 10;
			c[i + 1]--;
		}
	}
	c.trim();
	return c;
}

bigint operator*(const bigint& a, const bigint& b) {
	bigint c;
	c.sign = a.sign * b.sign;
	c.len = a.len + b.len;
	c.num = new int[c.len];
	memset(c.num, 0, c.len * sizeof(int));
	for (int i = 0; i < a.len; ++i)
		for (int j = 0; j < b.len; ++j)
			c[i + j] += a[i] * b[j];
	c.correct();
	c.trim();
	assert(c.len <= L);
	return c;
}

struct line {
	int level;
	string s;
	line(int tmp) {
		level = tmp;
		s = "";
	}
	line(string data) {
		assert((int) data.size() <= L);
		s = data;
		level = 0;
		while (s[0] == ' ') {
			level++;
			s.erase(s.begin());
		}
		assert(level % 4 == 0);
		level /= 4;
	}
};

map<string, bigint> var;
map<string, int> ans;
vector<line> lines;
int cur_line, cur_level, pos;
string token, s;

void initialize_token() {
	s = lines[cur_line].s;
	if (s[s.length() - 1] != ':')
		s.pb(':');
	pos = 0;
}

bool iscompare(char c) {
	return ((c == '>') || (c == '<') || (c == '=') || (c == '!'));
}

string next_token() {
	while (s[pos] == ' ')
		++pos;
	token = "";
	if (isdigit(s[pos])) {
		while (isdigit(s[pos]))
			token.pb(s[pos++]);
	} else if (isalpha(s[pos])) {
		while (isalpha(s[pos]))
			token.pb(s[pos++]);
	} else if (iscompare(s[pos])) {
		while (iscompare(s[pos]))
			token.pb(s[pos++]);
	} else
		token.pb(s[pos++]);
	return token;
}

bigint apply(const bigint& a, const bigint& b, string op) {
	ans[op]++;
	if (op == "+")
		return a + b;
	if (op == "-")
		return a - b;
	if (op == "*")
		return a * b;
	if (op == ">")
		return b < a;
	if (op == "<")
		return a < b;
	if (op == "<=")
		return a <= b;
	if (op == ">=")
		return b <= a;
	if (op == "==")
		return a == b;
	if (op == "!=")
		return !(a == b);
	if (op == "or")
		return a || b;
	assert(op == "and");
	return a && b;
}

bigint apply(bigint a, string op) {
	ans[op]++;
	if (op == "-")
		return a.negate();
	assert(op == "not");
	return !a;
}

int get_priority(string op) {
	if ((op == ":") || (op == "(") || (op == ")"))
		return 0;
	if ((op == "and") || (op == "or"))
		return 1;
	if ((op == "<") || (op == ">") || (op == "<=") || (op == ">=") || (op == "==") || (op == "!="))
		return 2;
	if ((op == "+") || (op == "-"))
		return 3;
	assert(op == "*");
	return 4;
}

bigint arithmetic_evaluate(int priority = 1) {
	if (priority == max_priority) {
		if (token == "(") {
			next_token();
			bigint res = arithmetic_evaluate();
			assert(token == ")");
			next_token();
			return res;
		} else if ((token == "not") || (token == "-")) {
			string op = token;
			next_token();
			bigint res = arithmetic_evaluate(priority);
			return apply(res, op);
		} else if (isalpha(token[0])) {
			assert(var.count(token));
			bigint res = var[token];
			next_token();
			return res;
		} else {
			assert(isdigit(token[0]));
			bigint res(token);
			next_token();
			return res;
		}
	} else {
		bigint res = arithmetic_evaluate(priority + 1);
		while (get_priority(token) == priority) {
			string op = token;
			next_token();
			res = apply(res, arithmetic_evaluate(priority + 1), op);
		}
		return res;
	}
}

void parse_program(int level = 0) {
	while (lines[cur_line].level == level) {
		initialize_token();
		string command = next_token();
		int start_line = cur_line;
		if ((command == "if") || (command == "while")) {
			next_token();
			cur_line++;
			bool cond = arithmetic_evaluate().is_true();
			assert((token == ":") && (pos == (int) s.length()));
			if (cond) {
				parse_program(level + 1);
				assert(cur_line != start_line + 1);
				if (command == "while")
					cur_line = start_line;
			} else while (lines[cur_line].level > level)
				++cur_line;
		} else {
			assert(next_token() == "=");
			ans[token]++;
			next_token();
			assert((int) command.length() <= 50);
			assert((command != "or") && (command != "and") && (command != "not") && (command != "while") && (command != "if"));
			for (int i = 0; i < (int) command.length(); ++i)
				assert((command[i] >= 'a') && (command[i] <= 'z'));
			var[command] = arithmetic_evaluate();
			assert((token == ":") && (pos == (int) s.length()));
			cur_line++;
		}
	}
}

void read_data() {
	string tmp;
	while (getline(cin, tmp))
		lines.pb(line(tmp));
	assert((int) lines.size() <= 5000);
	lines.pb(line(-1));
}

int main() {
	//freopen("parser.in", "r", stdin);
	//freopen("parser.out", "w", stdout);
	read_data();
	parse_program();
	int sum = 0;
	for (map<string, int>::iterator it = ans.begin(); it != ans.end(); ++it) {
		printf("%s: %d\n", it->first.data(), it->second);
		sum += it->second;
	}
	printf("total %d operations\n", sum);
	assert(sum <= max_sum);
	printf("\n");
	for (map<string, bigint>::iterator it = var.begin(); it != var.end(); ++it)
		printf("%s: %s\n", it->first.data(), it->second.to_string().data());
	return 0;
}
