#include <iostream>
#include <cstdio>
#include <string>
#include <memory.h>
#include <vector>
#include <cassert>
#include <algorithm>
#include <ctime>
#include <cmath>
using namespace std;

const int N = 52;
int A[N][N];
int K;

double start_time;

int greedy_solve(int * p){
    int wasA[N], wasB[N];
    memset(wasA, 0, sizeof(wasA));
    memset(wasB, 0, sizeof(wasB));
    vector<pair<int, pair<int, int> > > edges;
    for (int i = 0; i < K; ++i)
        for (int j = 0; j < K; ++j)
            edges.push_back(make_pair(A[i][j], make_pair(i, j)));
    sort(edges.begin(), edges.end());
    reverse(edges.begin(), edges.end());
    int ans = 0;
    for (int i = 0; i < (int)edges.size(); ++i){
        if (wasA[edges[i].second.first] || wasB[edges[i].second.second])
            continue;
        wasA[edges[i].second.first] = true;
        wasB[edges[i].second.second] = true;
        p[edges[i].second.first] = edges[i].second.second;
        ans += edges[i].first;
    }
    return ans;
}

typedef struct solution{
    int perm[N];
    solution(){
        greedy_solve(perm);
    }
    solution(solution & x){
        for (int i = 0; i < K; ++i)
            perm[i] = x.perm[i];
    }
    int cost(){
        int res = 0;
        for (int i = 0; i < K; ++i)
            res += A[i][perm[i]];
        return res;
    }
    solution get_next(double t, double t0){
        solution res(*this);
        int cnt = 2 * K * t / t0 + 1;
        for (int i = 0; i < cnt; ++i)
            swap(res.perm[rand() % K], res.perm[rand() % K]);
        return res;
    }
} solution;


bool TLE(){
    return (clock() - start_time) / CLOCKS_PER_SEC > 0.96;
}

bool admit(int dF, double t, double t0){
    if (dF > 0)
        return true;
    return exp(dF / t) > (double)rand() / RAND_MAX;
}

pair<int, vector<int> > solve(){
    solution cur, best, next;
    double t, t0, alpha;
    t0 = 1e4;
    t = t0 / 2;;
    alpha = 0.9999;
    while (!TLE()){
        next = cur.get_next(t, t0);
        if (admit(next.cost() - cur.cost(), t, t0)){
            cur = next;
            if (cur.cost() > best.cost())
                best = cur;
        }
        
        t *= alpha;
    }
    return make_pair(best.cost(), vector<int>(best.perm, best.perm + N));
}

int to_number(char c){
    if ('a' <= c && c <='z')
        return c - 'a';
    else
        return c - 'A' + 26;
}

char to_letter(int i){
    if (i < 26)
        return i + 'a';
    else
        return i - 26 + 'A';
}

int main(){
    start_time = clock();
    int n;
    cin >> n >> K;
    string first, second;
    cin >> first >> second;
    
    assert(first.length() == second.length());
    for (int i = 0; i < (int)first.length(); ++i)
        A[to_number(first[i])][to_number(second[i])]++;
    
    pair<int, vector<int> > ans = solve();
    cout << ans.first << endl;
    for (int i = 0; i < K; ++i)
        cout << to_letter(ans.second[i]);
    cout << endl;
    
    cerr << (clock() - start_time) / CLOCKS_PER_SEC << endl;
    return 0;
}
