#include <iostream>
#include <cstdio>
#include <string>
#include <memory.h>
#include <vector>
#include <cassert>
#include <ctime>
#include <algorithm>
using namespace std;

const int N = 52;
int A[N][N];
int K;

double start_time;

int greedy_solve(int * p){
    int wasA[N], wasB[N];
    memset(wasA, 0, sizeof(wasA));
    memset(wasB, 0, sizeof(wasB));
    vector<pair<int, pair<int, int> > > edges;
    for (int i = 0; i < K; ++i)
        for (int j = 0; j < K; ++j)
            edges.push_back(make_pair(A[i][j], make_pair(i, j)));
    sort(edges.begin(), edges.end());
    reverse(edges.begin(), edges.end());
    int ans = 0;
    for (int i = 0; i < (int)edges.size(); ++i){
        if (wasA[edges[i].second.first] || wasB[edges[i].second.second])
            continue;
        wasA[edges[i].second.first] = true;
        wasB[edges[i].second.second] = true;
        p[edges[i].second.first] = edges[i].second.second;
        ans += edges[i].first;
    }
    return ans;
}

bool TLE(){
    return (clock() - start_time) / CLOCKS_PER_SEC > 0.95;
}

int calc(int * p){
    int ans = 0;
    for (int i = 0; i < K; ++i)
        ans += A[i][p[i]];
    return ans;
}

pair<int,  vector<int> > solve(){
    int p[N];
    greedy_solve(p);

    int ans = calc(p);
    while (!TLE()){
        for (int i = 0; i < K; ++i)
            for (int j = 0; j < K; ++j){
                swap(p[i], p[j]);
                int curans  = calc(p);
                if (curans > ans)
                    ans = curans;
                else
                    swap(p[i], p[j]);
            }
    }
    
    return make_pair(ans, vector<int>(p, p + N));
}

int to_number(char c){
    if ('a' <= c && c <='z')
        return c - 'a';
    else
        return c - 'A' + 26;
}

char to_letter(int i){
    if (i < 26)
        return i + 'a';
    else
        return i - 26 + 'A';
}

int main(){
    start_time = clock();
    int n;
    cin >> n >> K;
    string first, second;
    cin >> first >> second;
    
    assert(first.length() == second.length());
    for (int i = 0; i < (int)first.length(); ++i)
        A[to_number(first[i])][to_number(second[i])]++;
    
    pair<int, vector<int> > ans = solve();
    cout << ans.first << endl;
    for (int i = 0; i < K; ++i)
        cout << to_letter(ans.second[i]);
    cout << endl;
    
    cerr << (clock() - start_time) / CLOCKS_PER_SEC << endl;
    return 0;
}
