#include <iostream>
#include <cstdio>
#include <string>
#include <memory.h>
#include <vector>
#include <cassert>
#include <ctime>
#include <algorithm>
using namespace std;

const int N = 52;
int A[N][N];
int K;

double start_time;

int greedy_solve(int * p){
    int wasA[N], wasB[N];
    memset(wasA, 0, sizeof(wasA));
    memset(wasB, 0, sizeof(wasB));
    vector<pair<int, pair<int, int> > > edges;
    for (int i = 0; i < K; ++i)
        for (int j = 0; j < K; ++j)
            edges.push_back(make_pair(A[i][j], make_pair(i, j)));
    sort(edges.begin(), edges.end());
    reverse(edges.begin(), edges.end());
    int ans = 0;
    for (int i = 0; i < (int)edges.size(); ++i){
        if (wasA[edges[i].second.first] || wasB[edges[i].second.second])
            continue;
        wasA[edges[i].second.first] = true;
        wasB[edges[i].second.second] = true;
        p[edges[i].second.first] = edges[i].second.second;
        ans += edges[i].first;
    }
    return ans;
}

bool TLE(){
    return (clock() - start_time) / CLOCKS_PER_SEC > 0.97;
}

int calc(int * p){
    int ans = 0;
    for (int i = 0; i < K; ++i)
        ans += A[i][p[i]];
    return ans;
}

bool correct(int * p){
    int was[N];
    for (int i = 0; i < K; ++i)
        was[i] = 0;
    for (int i = 0; i < K; ++i)
        was[p[i]]++;
    for (int i = 0; i < K; ++i)
        if (was[i] != 1)
            return false;
    return true;
}

void opt(int * p, int v, int it){
    int p1[N], to_swap[N];
    int perm[N], best_perm[N];
    for (int i = 0; i < K; ++i)
        p1[i] = p[i], to_swap[i] = i;

    int best = calc(p);
    for (int i = 0; i < it; ++i){
        if (TLE())
            return;
        random_shuffle(to_swap, to_swap + K);
        for (int j = 0; j < v; ++j)
            perm[j] = best_perm[j] = j;
            
        int it1 = 0;
        do{
            it1++;
            if (it1 > 1000){
                it1 = 0;
                if (TLE())
                    return;
            }
            for (int j = 0; j < v; ++j)
                p1[to_swap[perm[j]]] = p[to_swap[j]];
            int cur = calc(p1);
            if (cur > best){
                for (int j = 0; j < v; ++j)
                    best_perm[j] = perm[j];
                best = cur;
            }
        } while (next_permutation(perm, perm + v));
        
        for (int j = 0; j < v; ++j)
            p1[to_swap[best_perm[j]]] = p[to_swap[j]];
        for (int j = 0; j < v; ++j)
            p[to_swap[j]] = p1[to_swap[j]];
    }
}

pair<int, vector<int> > solve(){
    int p[N];
    greedy_solve(p);
    
    while (!TLE()){
    int ans = calc(p);
    for (int i = 0; i < K; ++i)
        for (int j = 0; j < K; ++j){
            swap(p[i], p[j]);
            int curans  = calc(p);
            if (curans > ans)
                ans = curans;
            else
                swap(p[i], p[j]);
        }
    long long fact = 2;
    long long Nfact = K * (K - 1) * (K - 2) / 6;
    for (int i = 3; i <= min(K, 9); ++i){
        fact *= (long long) i;
        if (Nfact <= 1e9)
            Nfact = Nfact * (K - i) / i;
        opt(p, i, min(20000000 / 26 / fact, 2 * Nfact));
    }
    }
    
    return make_pair(calc(p), vector<int>(p, p + N));
}

int to_number(char c){
    if ('a' <= c && c <='z')
        return c - 'a';
    else
        return c - 'A' + 26;
}

char to_letter(int i){
    if (i < 26)
        return i + 'a';
    else
        return i - 26 + 'A';
}

int main(){
    start_time = clock();
    int n;
    cin >> n >> K;
    string first, second;
    cin >> first >> second;
    
    assert(first.length() == second.length());
    for (int i = 0; i < (int)first.length(); ++i)
        A[to_number(first[i])][to_number(second[i])]++;
    
    pair<int, vector<int> > ans = solve();
    cout << ans.first << endl;
    for (int i = 0; i < K; ++i)
        cout << to_letter(ans.second[i]);
    cout << endl;
    
    cerr << (clock() - start_time) / CLOCKS_PER_SEC << endl;
    return 0;
}
